@@ -2,9 +2,10 @@
 
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
-    WWW:           http://www.swi-prolog.org
-    Copyright (c)  2002-2013, University of Amsterdam
+    WWW:           https://www.swi-prolog.org
+    Copyright (c)  2002-2025, University of Amsterdam
                               VU University Amsterdam
+                              SWI-Prolog Solutions b.v.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -52,12 +53,12 @@ This library defines  the  class   prolog_thread_monitor,  a  frame that
 displays the status of threads.
 */
 
-resource(running,   image, library('trace/icons/mini-run.xpm')).
-resource(true,      image, image('16x16/ok.xpm')).
-resource(false,     image, image('16x16/false.xpm')).
-resource(exception, image, image('16x16/error.xpm')).
-resource(exited,    image, image('16x16/done.xpm')).
-resource(profiling, image, image('16x16/profiler.xpm')).
+resource(running,   image, library('trace/icons/mini-run.png')).
+resource(true,      image, image('16x16/ok.png')).
+resource(false,     image, image('16x16/false.png')).
+resource(exception, image, image('16x16/error.png')).
+resource(exited,    image, image('16x16/done.png')).
+resource(profiling, image, image('16x16/profiler.png')).
 
 
 :- pce_begin_class(thread_statistics, object,
@@ -162,7 +163,8 @@ state(TS, State:name, Style:[name]) :->
         send(TS, style, TheStyle)
     ).
 
-recall(TS, Recall:'1..') :->
+recall(TS, Recall0:int) :->
+    Recall is max(1, Recall0),
     send(TS, slot, recall, Recall),
     get(TS, object, History),
     truncate_chain(History, Recall).
@@ -323,19 +325,16 @@ running_styles(TB) :->
     get(TB, font, Font),
     get(Font, ascent, Ascent),
     get(Font, descent, Descent),
-    H is Ascent+Descent,
+    H is floor(Ascent+Descent),
     send(TB, slot, cpu_height, H),
     new(Running, image(resource(running))),
-    get(Running, size, size(W,_IH)),
+    get(Running, size, size(W,IH)),
     (   between(0, H, N),
         new(Img, image(@nil, W, H, pixmap)),
         send(Img, hot_spot, point(0, Ascent)),
-        send(Img, background, grey80),
-        send(Img, foreground, green),
-        forall(between(0,N,I),
-               (   Y is H-I,
-                   send(Img, draw_in, line(0,Y,W,Y)))),
-        send(Img, draw_in, bitmap(Running)),
+        send(Img, fill, grey80),
+        send(Img, fill, green, area(0, H-N, W, N)),
+        send(Img, draw_in, bitmap(Running), point(0,Ascent-IH)),
         atom_concat(running_, N, Style),
         send(TB, style, Style, style(icon := Img)),
         fail
@@ -370,8 +369,9 @@ thread_id_status(Id, Status) :-
 :- endif.
 
 
-recall(TB, Recall:'1..') :->
+recall(TB, Recall0:int) :->
     "Recall this many samples"::
+    Recall is max(Recall0, 1),
     send(TB, slot, recall, Recall),
     get(TB, dict, Dict),
     send(Dict, for_all, message(@arg1, recall, Recall)).
@@ -661,12 +661,12 @@ graphs(Win, Graphs:chain) :->
 :- pce_begin_class(prolog_thread_monitor, persistent_frame,
                    "Monitor thread-activity").
 
-variable(timer,           timer*,     get, "Update timer").
-variable(graphs,          chain,      get, "Which graphs are shown").
-variable(update_interval, 'int|real*', get, "Update interval").
+variable(timer,           timer*,  get, "Update timer").
+variable(graphs,          chain,   get, "Which graphs are shown").
+variable(update_interval, num*,    get, "Update interval").
 
-class_variable(update_interval, 'int|real*', 0.2).
-class_variable(graphs,          chain,      chain(local,global,trail,cpu)).
+class_variable(update_interval, num*,  0.2).
+class_variable(graphs,          chain, chain(local,global,trail,cpu)).
 
 initialise(TM) :->
     send_super(TM, initialise, 'SWI-Prolog thread monitor'),
@@ -694,7 +694,7 @@ fill_tool_dialog(TM, TD:tool_dialog) :->
     send_list(File, append,
               [ menu_item(settings, message(TM, settings)),
                 gap,
-                menu_item(exit, message(TM, destroy))
+                menu_item(quit, message(TM, destroy))
               ]),
     send_list(Threads, append,
               [ menu_item(new,
@@ -739,7 +739,7 @@ selection(TM, Thread:'name|int') :->
     send(TB, selection, DI),
     send(TB, details, DI).
 
-recall(TM, Recall:'1..') :->
+recall(TM, Recall:int) :->
     "#samples recalled"::
     get(TM, member, thread_browser, TB),
     send(TB, recall, Recall).
